@@ -21,7 +21,7 @@
 /*!
   @file    value.hpp
   @brief   Value interface and concrete subclasses
-  @version $Rev: 1750 $
+  @version $Rev: 1802 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @date    09-Jan-04, ahu: created
@@ -1478,7 +1478,9 @@ namespace Exiv2 {
     int ValueType<T>::read(const byte* buf, long len, ByteOrder byteOrder)
     {
         value_.clear();
-        for (long i = 0; i < len; i += TypeInfo::typeSize(typeId())) {
+        long ts = TypeInfo::typeSize(typeId());
+        if (len % ts != 0) len = (len / ts) * ts;
+        for (long i = 0; i < len; i += ts) {
             value_.push_back(getValue<T>(buf + i, byteOrder));
         }
         return 0;
